"""
List of HTML default tag styles.
"""

html_styles = [
    {
        "selectorText": "[hidden], area, base, basefont, datalist, head, link, meta,\nnoembed, noframes, param, rp, script, source, style, template, track, title",
        "type": "CSSStyleRule",
        "style": {"display": "none"},
    },
    {
        "selectorText": "embed[hidden]",
        "type": "CSSStyleRule",
        "style": {"display": "inline", "height": "0", "width": "0"},
    },
    {
        "selectorText": "input[type=hidden i]",
        "type": "CSSStyleRule",
        "style": {"display": "none"},
    },
    {
        "selectorText": "html, body",
        "type": "CSSStyleRule",
        "style": {"display": "block"},
    },
    {
        "selectorText": "address, blockquote, center, div, figure, figcaption, footer, form, header, hr,\nlegend, listing, main, p, plaintext, pre, xmp",
        "type": "CSSStyleRule",
        "style": {"display": "block"},
    },
    {
        "selectorText": "blockquote, figure, listing, p, plaintext, pre, xmp",
        "type": "CSSStyleRule",
        "style": {"margin-block-start": "1em", "margin-block-end": "1em"},
    },
    {
        "selectorText": "blockquote, figure",
        "type": "CSSStyleRule",
        "style": {"margin-inline-start": "40px", "margin-inline-end": "40px"},
    },
    {
        "selectorText": "address",
        "type": "CSSStyleRule",
        "style": {"font-style": "italic"},
    },
    {
        "selectorText": "listing, plaintext, pre, xmp",
        "type": "CSSStyleRule",
        "style": {"font-family": "monospace", "white-space": "pre"},
    },
    {
        "selectorText": "dialog:not([open])",
        "type": "CSSStyleRule",
        "style": {"display": "none"},
    },
    {
        "selectorText": "dialog",
        "type": "CSSStyleRule",
        "style": {
            "position": "absolute",
            "left": "0",
            "right": "0",
            "width": "fit-content",
            "height": "fit-content",
            "margin": "auto",
            "border": "solid",
            "padding": "1em",
            "background": "white",
            "color": "black",
        },
    },
    {
        "selectorText": "dialog::backdrop",
        "type": "CSSStyleRule",
        "style": {"background": "rgba(0,0,0,0.1)"},
    },
    {"selectorText": "slot", "type": "CSSStyleRule", "style": {"display": "contents"}},
    {
        "selectorText": "pre[wrap]",
        "type": "CSSStyleRule",
        "style": {"white-space": "pre-wrap"},
    },
    {
        "selectorText": "form",
        "type": "CSSStyleRule",
        "style": {"margin-block-end": "1em"},
    },
    {
        "selectorText": "cite, dfn, em, i, var",
        "type": "CSSStyleRule",
        "style": {"font-style": "italic"},
    },
    {
        "selectorText": "b, strong",
        "type": "CSSStyleRule",
        "style": {"font-weight": "bolder"},
    },
    {
        "selectorText": "code, kbd, samp, tt",
        "type": "CSSStyleRule",
        "style": {"font-family": "monospace"},
    },
    {"selectorText": "big", "type": "CSSStyleRule", "style": {"font-size": "larger"}},
    {
        "selectorText": "small",
        "type": "CSSStyleRule",
        "style": {"font-size": "smaller"},
    },
    {"selectorText": "sub", "type": "CSSStyleRule", "style": {"vertical-align": "sub"}},
    {
        "selectorText": "sup",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "super"},
    },
    {
        "selectorText": "sub, sup",
        "type": "CSSStyleRule",
        "style": {"line-height": "normal", "font-size": "smaller"},
    },
    {"selectorText": "ruby", "type": "CSSStyleRule", "style": {"display": "ruby"}},
    {"selectorText": "rt", "type": "CSSStyleRule", "style": {"display": "ruby-text"}},
    {"selectorText": ":link", "type": "CSSStyleRule", "style": {"color": "#0000EE"}},
    {"selectorText": ":visited", "type": "CSSStyleRule", "style": {"color": "#551A8B"}},
    {
        "selectorText": ":link:active, :visited:active",
        "type": "CSSStyleRule",
        "style": {"color": "#FF0000"},
    },
    {
        "selectorText": ":link, :visited",
        "type": "CSSStyleRule",
        "style": {"text-decoration": "underline", "cursor": "pointer"},
    },
    {
        "selectorText": "a:link[rel~=help], a:visited[rel~=help],\narea:link[rel~=help], area:visited[rel~=help]",
        "type": "CSSStyleRule",
        "style": {"cursor": "help"},
    },
    {"selectorText": ":focus", "type": "CSSStyleRule", "style": {"outline": "auto"}},
    {
        "selectorText": "mark",
        "type": "CSSStyleRule",
        "style": {"background": "yellow", "color": "black"},
    },
    {
        "selectorText": "abbr[title], acronym[title]",
        "type": "CSSStyleRule",
        "style": {"text-decoration": "dotted underline"},
    },
    {
        "selectorText": "ins, u",
        "type": "CSSStyleRule",
        "style": {"text-decoration": "underline"},
    },
    {
        "selectorText": "del, s, strike",
        "type": "CSSStyleRule",
        "style": {"text-decoration": "line-through"},
    },
    {
        "selectorText": "blink",
        "type": "CSSStyleRule",
        "style": {"text-decoration": "blink"},
    },
    {
        "selectorText": "q::before",
        "type": "CSSStyleRule",
        "style": {"content": "open-quote"},
    },
    {
        "selectorText": "q::after",
        "type": "CSSStyleRule",
        "style": {"content": "close-quote"},
    },
    {
        "selectorText": "br",
        "type": "CSSStyleRule",
        "style": {"display-outside": "newline"},
    },
    {
        "selectorText": "nobr",
        "type": "CSSStyleRule",
        "style": {"white-space": "nowrap"},
    },
    {
        "selectorText": "wbr",
        "type": "CSSStyleRule",
        "style": {"display-outside": "break-opportunity"},
    },
    {
        "selectorText": "nobr wbr",
        "type": "CSSStyleRule",
        "style": {"white-space": "normal"},
    },
    {
        "selectorText": "br[clear=left i]",
        "type": "CSSStyleRule",
        "style": {"clear": "left"},
    },
    {
        "selectorText": "br[clear=right i]",
        "type": "CSSStyleRule",
        "style": {"clear": "right"},
    },
    {
        "selectorText": "br[clear=all i], br[clear=both i]",
        "type": "CSSStyleRule",
        "style": {"clear": "both"},
    },
    {
        "selectorText": "[dir]:dir(ltr), bdi:dir(ltr), input[type=tel i]:dir(ltr)",
        "type": "CSSStyleRule",
        "style": {"direction": "ltr"},
    },
    {
        "selectorText": "[dir]:dir(rtl), bdi:dir(rtl)",
        "type": "CSSStyleRule",
        "style": {"direction": "rtl"},
    },
    {
        "selectorText": "address, blockquote, center, div, figure, figcaption, footer, form, header, hr,\nlegend, listing, main, p, plaintext, pre, summary, xmp, article, aside, h1, h2,\nh3, h4, h5, h6, hgroup, nav, section, table, caption, colgroup, col, thead,\ntbody, tfoot, tr, td, th, dir, dd, dl, dt, ol, ul, li, bdi, output,\n[dir=ltr i], [dir=rtl i], [dir=auto i]",
        "type": "CSSStyleRule",
        "style": {"unicode-bidi": "isolate"},
    },
    {
        "selectorText": "bdo, bdo[dir]",
        "type": "CSSStyleRule",
        "style": {"unicode-bidi": "isolate-override"},
    },
    {
        "selectorText": "input[dir=auto i][type=search i], input[dir=auto i][type=tel i], input[dir=auto i][type=url i], input[dir=auto i][type=email i], textarea[dir=auto i], pre[dir=auto i]",
        "type": "CSSStyleRule",
        "style": {"unicode-bidi": "plaintext"},
    },
    {
        "selectorText": "address, blockquote, center, div, figure, figcaption, footer, form, header, hr,\nlegend, listing, main, p, plaintext, pre, summary, xmp, article, aside, h1, h2,\nh3, h4, h5, h6, hgroup, nav, section, table, caption, colgroup, col, thead,\ntbody, tfoot, tr, td, th, dir, dd, dl, dt, ol, ul, li, [dir=ltr i],\n[dir=rtl i], [dir=auto i], *|*",
        "type": "CSSStyleRule",
        "style": {"unicode-bidi": "bidi-override"},
    },
    {
        "selectorText": "input:not([type=submit i]):not([type=reset i]):not([type=button i]),\ntextarea",
        "type": "CSSStyleRule",
        "style": {"unicode-bidi": "normal"},
    },
    {
        "selectorText": "article, aside, h1, h2, h3, h4, h5, h6, hgroup, nav, section",
        "type": "CSSStyleRule",
        "style": {"display": "block"},
    },
    {
        "selectorText": "h1",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "0.67em",
            "margin-block-end": "0.67em",
            "font-size": "2.00em",
            "font-weight": "bold",
        },
    },
    {
        "selectorText": "h2",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "0.83em",
            "margin-block-end": "0.83em",
            "font-size": "1.50em",
            "font-weight": "bold",
        },
    },
    {
        "selectorText": "h3",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.00em",
            "margin-block-end": "1.00em",
            "font-size": "1.17em",
            "font-weight": "bold",
        },
    },
    {
        "selectorText": "h4",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.33em",
            "margin-block-end": "1.33em",
            "font-size": "1.00em",
            "font-weight": "bold",
        },
    },
    {
        "selectorText": "h5",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.67em",
            "margin-block-end": "1.67em",
            "font-size": "0.83em",
            "font-weight": "bold",
        },
    },
    {
        "selectorText": "h6",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "2.33em",
            "margin-block-end": "2.33em",
            "font-size": "0.67em",
            "font-weight": "bold",
        },
    },
    {
        "selectorText": "x h1",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "0.83em",
            "margin-block-end": "0.83em",
            "font-size": "1.50em",
        },
    },
    {
        "selectorText": "x x h1",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.00em",
            "margin-block-end": "1.00em",
            "font-size": "1.17em",
        },
    },
    {
        "selectorText": "x x x h1",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.33em",
            "margin-block-end": "1.33em",
            "font-size": "1.00em",
        },
    },
    {
        "selectorText": "x x x x h1",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.67em",
            "margin-block-end": "1.67em",
            "font-size": "0.83em",
        },
    },
    {
        "selectorText": "x x x x x h1",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "2.33em",
            "margin-block-end": "2.33em",
            "font-size": "0.67em",
        },
    },
    {
        "selectorText": "x hgroup > h1 ~ h2",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.00em",
            "margin-block-end": "1.00em",
            "font-size": "1.17em",
        },
    },
    {
        "selectorText": "x x hgroup > h1 ~ h2",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.33em",
            "margin-block-end": "1.33em",
            "font-size": "1.00em",
        },
    },
    {
        "selectorText": "x x x hgroup > h1 ~ h2",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.67em",
            "margin-block-end": "1.67em",
            "font-size": "0.83em",
        },
    },
    {
        "selectorText": "x x x x hgroup > h1 ~ h2",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "2.33em",
            "margin-block-end": "2.33em",
            "font-size": "0.67em",
        },
    },
    {
        "selectorText": "x hgroup > h1 ~ h3",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.33em",
            "margin-block-end": "1.33em",
            "font-size": "1.00em",
        },
    },
    {
        "selectorText": "x x hgroup > h1 ~ h3",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.67em",
            "margin-block-end": "1.67em",
            "font-size": "0.83em",
        },
    },
    {
        "selectorText": "x x x hgroup > h1 ~ h3",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "2.33em",
            "margin-block-end": "2.33em",
            "font-size": "0.67em",
        },
    },
    {
        "selectorText": "x hgroup > h1 ~ h4",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "1.67em",
            "margin-block-end": "1.67em",
            "font-size": "0.83em",
        },
    },
    {
        "selectorText": "x x hgroup > h1 ~ h4",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "2.33em",
            "margin-block-end": "2.33em",
            "font-size": "0.67em",
        },
    },
    {
        "selectorText": "x hgroup > h1 ~ h5",
        "type": "CSSStyleRule",
        "style": {
            "margin-block-start": "2.33em",
            "margin-block-end": "2.33em",
            "font-size": "0.67em",
        },
    },
    {
        "selectorText": "dir, dd, dl, dt, ol, ul",
        "type": "CSSStyleRule",
        "style": {"display": "block"},
    },
    {"selectorText": "li", "type": "CSSStyleRule", "style": {"display": "list-item"}},
    {
        "selectorText": "dir, dl, ol, ul",
        "type": "CSSStyleRule",
        "style": {"margin-block-start": "1em", "margin-block-end": "1em"},
    },
    {
        "selectorText": "dir dir, dl dir, ol dir, ul dir, dir dl, dl dl, ol dl, ul dl, dir ol, dl ol, ol ol, ul ol, dir ul, dl ul, ol ul, ul ul",
        "type": "CSSStyleRule",
        "style": {"margin-block-start": "0", "margin-block-end": "0"},
    },
    {
        "selectorText": "dd",
        "type": "CSSStyleRule",
        "style": {"margin-inline-start": "40px"},
    },
    {
        "selectorText": "dir, ol, ul",
        "type": "CSSStyleRule",
        "style": {"padding-inline-start": "40px"},
    },
    {
        "selectorText": "ol",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "decimal"},
    },
    {
        "selectorText": "dir, ul",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "disc"},
    },
    {
        "selectorText": "dir dir, ol dir, ul dir, dir ul, ol ul, ul ul",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "circle"},
    },
    {
        "selectorText": "dir dir dir, ol dir dir, ul dir dir, dir ol dir, ol ol dir, ul ol dir, dir ul dir, ol ul dir, ul ul dir, dir dir ul, ol dir ul, ul dir ul, dir ol ul, ol ol ul, ul ol ul, dir ul ul, ol ul ul, ul ul ul",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "square"},
    },
    {
        "selectorText": 'ol[type="1"], li[type="1"]',
        "type": "CSSStyleRule",
        "style": {"list-style-type": "decimal"},
    },
    {
        "selectorText": "ol[type=a], li[type=a]",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "lower-alpha"},
    },
    {
        "selectorText": "ol[type=A], li[type=A]",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "upper-alpha"},
    },
    {
        "selectorText": "ol[type=i], li[type=i]",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "lower-roman"},
    },
    {
        "selectorText": "ol[type=I], li[type=I]",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "upper-roman"},
    },
    {
        "selectorText": "ul[type=none i], li[type=none i]",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "none"},
    },
    {
        "selectorText": "ul[type=disc i], li[type=disc i]",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "disc"},
    },
    {
        "selectorText": "ul[type=circle i], li[type=circle i]",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "circle"},
    },
    {
        "selectorText": "ul[type=square i], li[type=square i]",
        "type": "CSSStyleRule",
        "style": {"list-style-type": "square"},
    },
    {"selectorText": "table", "type": "CSSStyleRule", "style": {"display": "table"}},
    {
        "selectorText": "caption",
        "type": "CSSStyleRule",
        "style": {"display": "table-caption"},
    },
    {
        "selectorText": "colgroup, colgroup[hidden]",
        "type": "CSSStyleRule",
        "style": {"display": "table-column-group"},
    },
    {
        "selectorText": "col, col[hidden]",
        "type": "CSSStyleRule",
        "style": {"display": "table-column"},
    },
    {
        "selectorText": "thead, thead[hidden]",
        "type": "CSSStyleRule",
        "style": {"display": "table-header-group"},
    },
    {
        "selectorText": "tbody, tbody[hidden]",
        "type": "CSSStyleRule",
        "style": {"display": "table-row-group"},
    },
    {
        "selectorText": "tfoot, tfoot[hidden]",
        "type": "CSSStyleRule",
        "style": {"display": "table-footer-group"},
    },
    {
        "selectorText": "tr, tr[hidden]",
        "type": "CSSStyleRule",
        "style": {"display": "table-row"},
    },
    {
        "selectorText": "td, th, td[hidden], th[hidden]",
        "type": "CSSStyleRule",
        "style": {"display": "table-cell"},
    },
    {
        "selectorText": "colgroup[hidden], col[hidden], thead[hidden], tbody[hidden],\ntfoot[hidden], tr[hidden], td[hidden], th[hidden]",
        "type": "CSSStyleRule",
        "style": {"visibility": "collapse"},
    },
    {
        "selectorText": "table",
        "type": "CSSStyleRule",
        "style": {
            "box-sizing": "border-box",
            "border-spacing": "2px",
            "border-collapse": "separate",
            "text-indent": "initial",
        },
    },
    {"selectorText": "td, th", "type": "CSSStyleRule", "style": {"padding": "1px"}},
    {"selectorText": "th", "type": "CSSStyleRule", "style": {"font-weight": "bold"}},
    {
        "selectorText": "caption",
        "type": "CSSStyleRule",
        "style": {"text-align": "center"},
    },
    {
        "selectorText": "thead, tbody, tfoot, table > tr",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "middle"},
    },
    {
        "selectorText": "tr, td, th",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "inherit"},
    },
    {
        "selectorText": "table, td, th",
        "type": "CSSStyleRule",
        "style": {"border-color": "gray"},
    },
    {
        "selectorText": "thead, tbody, tfoot, tr",
        "type": "CSSStyleRule",
        "style": {"border-color": "inherit"},
    },
    {
        "selectorText": "table[rules=none i], table[rules=groups i], table[rules=rows i],\ntable[rules=cols i], table[rules=all i], table[frame=void i],\ntable[frame=above i], table[frame=below i], table[frame=hsides i],\ntable[frame=lhs i], table[frame=rhs i], table[frame=vsides i],\ntable[frame=box i], table[frame=border i],\ntable[rules=none i] > tr > td, table[rules=none i] > tr > th,\ntable[rules=groups i] > tr > td, table[rules=groups i] > tr > th,\ntable[rules=rows i] > tr > td, table[rules=rows i] > tr > th,\ntable[rules=cols i] > tr > td, table[rules=cols i] > tr > th,\ntable[rules=all i] > tr > td, table[rules=all i] > tr > th,\ntable[rules=none i] > thead > tr > td, table[rules=none i] > thead > tr > th,\ntable[rules=groups i] > thead > tr > td, table[rules=groups i] > thead > tr > th,\ntable[rules=rows i] > thead > tr > td, table[rules=rows i] > thead > tr > th,\ntable[rules=cols i] > thead > tr > td, table[rules=cols i] > thead > tr > th,\ntable[rules=all i] > thead > tr > td, table[rules=all i] > thead > tr > th,\ntable[rules=none i] > tbody > tr > td, table[rules=none i] > tbody > tr > th,\ntable[rules=groups i] > tbody > tr > td, table[rules=groups i] > tbody > tr > th,\ntable[rules=rows i] > tbody > tr > td, table[rules=rows i] > tbody > tr > th,\ntable[rules=cols i] > tbody > tr > td, table[rules=cols i] > tbody > tr > th,\ntable[rules=all i] > tbody > tr > td, table[rules=all i] > tbody > tr > th,\ntable[rules=none i] > tfoot > tr > td, table[rules=none i] > tfoot > tr > th,\ntable[rules=groups i] > tfoot > tr > td, table[rules=groups i] > tfoot > tr > th,\ntable[rules=rows i] > tfoot > tr > td, table[rules=rows i] > tfoot > tr > th,\ntable[rules=cols i] > tfoot > tr > td, table[rules=cols i] > tfoot > tr > th,\ntable[rules=all i] > tfoot > tr > td, table[rules=all i] > tfoot > tr > th",
        "type": "CSSStyleRule",
        "style": {"border-color": "black"},
    },
    {
        "selectorText": "table[align=left i]",
        "type": "CSSStyleRule",
        "style": {"float": "left"},
    },
    {
        "selectorText": "table[align=right i]",
        "type": "CSSStyleRule",
        "style": {"float": "right"},
    },
    {
        "selectorText": "table[align=center i]",
        "type": "CSSStyleRule",
        "style": {"margin-inline-start": "auto", "margin-inline-end": "auto"},
    },
    {
        "selectorText": "thead[align=absmiddle i], tbody[align=absmiddle i], tfoot[align=absmiddle i],\ntr[align=absmiddle i], td[align=absmiddle i], th[align=absmiddle i]",
        "type": "CSSStyleRule",
        "style": {"text-align": "center"},
    },
    {
        "selectorText": "caption[align=bottom i]",
        "type": "CSSStyleRule",
        "style": {"caption-side": "bottom"},
    },
    {
        "selectorText": "p[align=left i], h1[align=left i], h2[align=left i], h3[align=left i],\nh4[align=left i], h5[align=left i], h6[align=left i]",
        "type": "CSSStyleRule",
        "style": {"text-align": "left"},
    },
    {
        "selectorText": "p[align=right i], h1[align=right i], h2[align=right i], h3[align=right i],\nh4[align=right i], h5[align=right i], h6[align=right i]",
        "type": "CSSStyleRule",
        "style": {"text-align": "right"},
    },
    {
        "selectorText": "p[align=center i], h1[align=center i], h2[align=center i], h3[align=center i],\nh4[align=center i], h5[align=center i], h6[align=center i]",
        "type": "CSSStyleRule",
        "style": {"text-align": "center"},
    },
    {
        "selectorText": "p[align=justify i], h1[align=justify i], h2[align=justify i], h3[align=justify i],\nh4[align=justify i], h5[align=justify i], h6[align=justify i]",
        "type": "CSSStyleRule",
        "style": {"text-align": "justify"},
    },
    {
        "selectorText": "thead[valign=top i], tbody[valign=top i], tfoot[valign=top i],\ntr[valign=top i], td[valign=top i], th[valign=top i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "top"},
    },
    {
        "selectorText": "thead[valign=middle i], tbody[valign=middle i], tfoot[valign=middle i],\ntr[valign=middle i], td[valign=middle i], th[valign=middle i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "middle"},
    },
    {
        "selectorText": "thead[valign=bottom i], tbody[valign=bottom i], tfoot[valign=bottom i],\ntr[valign=bottom i], td[valign=bottom i], th[valign=bottom i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "bottom"},
    },
    {
        "selectorText": "thead[valign=baseline i], tbody[valign=baseline i], tfoot[valign=baseline i],\ntr[valign=baseline i], td[valign=baseline i], th[valign=baseline i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "baseline"},
    },
    {
        "selectorText": "td[nowrap], th[nowrap]",
        "type": "CSSStyleRule",
        "style": {"white-space": "nowrap"},
    },
    {
        "selectorText": "table[rules=none i], table[rules=groups i], table[rules=rows i],\ntable[rules=cols i], table[rules=all i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "hidden", "border-collapse": "collapse"},
    },
    {
        "selectorText": "table[border]",
        "type": "CSSStyleRule",
        "style": {"border-style": "outset"},
    },
    {
        "selectorText": "table[frame=void i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "hidden"},
    },
    {
        "selectorText": "table[frame=above i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "outset hidden hidden hidden"},
    },
    {
        "selectorText": "table[frame=below i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "hidden hidden outset hidden"},
    },
    {
        "selectorText": "table[frame=hsides i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "outset hidden outset hidden"},
    },
    {
        "selectorText": "table[frame=lhs i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "hidden hidden hidden outset"},
    },
    {
        "selectorText": "table[frame=rhs i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "hidden outset hidden hidden"},
    },
    {
        "selectorText": "table[frame=vsides i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "hidden outset"},
    },
    {
        "selectorText": "table[frame=box i], table[frame=border i]",
        "type": "CSSStyleRule",
        "style": {"border-style": "outset"},
    },
    {
        "selectorText": "table[border] > tr > td, table[border] > tr > th,\ntable[border] > thead > tr > td, table[border] > thead > tr > th,\ntable[border] > tbody > tr > td, table[border] > tbody > tr > th,\ntable[border] > tfoot > tr > td, table[border] > tfoot > tr > th",
        "type": "CSSStyleRule",
        "style": {"border-width": "1px", "border-style": "inset"},
    },
    {
        "selectorText": "table[rules=none i] > tr > td, table[rules=none i] > tr > th,\ntable[rules=none i] > thead > tr > td, table[rules=none i] > thead > tr > th,\ntable[rules=none i] > tbody > tr > td, table[rules=none i] > tbody > tr > th,\ntable[rules=none i] > tfoot > tr > td, table[rules=none i] > tfoot > tr > th,\ntable[rules=groups i] > tr > td, table[rules=groups i] > tr > th,\ntable[rules=groups i] > thead > tr > td, table[rules=groups i] > thead > tr > th,\ntable[rules=groups i] > tbody > tr > td, table[rules=groups i] > tbody > tr > th,\ntable[rules=groups i] > tfoot > tr > td, table[rules=groups i] > tfoot > tr > th,\ntable[rules=rows i] > tr > td, table[rules=rows i] > tr > th,\ntable[rules=rows i] > thead > tr > td, table[rules=rows i] > thead > tr > th,\ntable[rules=rows i] > tbody > tr > td, table[rules=rows i] > tbody > tr > th,\ntable[rules=rows i] > tfoot > tr > td, table[rules=rows i] > tfoot > tr > th",
        "type": "CSSStyleRule",
        "style": {"border-width": "1px", "border-style": "none"},
    },
    {
        "selectorText": "table[rules=cols i] > tr > td, table[rules=cols i] > tr > th,\ntable[rules=cols i] > thead > tr > td, table[rules=cols i] > thead > tr > th,\ntable[rules=cols i] > tbody > tr > td, table[rules=cols i] > tbody > tr > th,\ntable[rules=cols i] > tfoot > tr > td, table[rules=cols i] > tfoot > tr > th",
        "type": "CSSStyleRule",
        "style": {
            "border-width": "1px",
            "block-start-style": "none",
            "border-inline-end-style": "solid",
            "border-block-end-style": "none",
            "border-inline-start-style": "solid",
        },
    },
    {
        "selectorText": "table[rules=all i] > tr > td, table[rules=all i] > tr > th,\ntable[rules=all i] > thead > tr > td, table[rules=all i] > thead > tr > th,\ntable[rules=all i] > tbody > tr > td, table[rules=all i] > tbody > tr > th,\ntable[rules=all i] > tfoot > tr > td, table[rules=all i] > tfoot > tr > th",
        "type": "CSSStyleRule",
        "style": {"border-width": "1px", "border-style": "solid"},
    },
    {
        "selectorText": "table[rules=groups i] > colgroup",
        "type": "CSSStyleRule",
        "style": {
            "border-inline-start-width": "1px",
            "border-inline-start-style": "solid",
            "border-inline-end-width": "1px",
            "border-inline-end-style": "solid",
        },
    },
    {
        "selectorText": "table[rules=groups i] > thead,\ntable[rules=groups i] > tbody,\ntable[rules=groups i] > tfoot",
        "type": "CSSStyleRule",
        "style": {
            "border-block-start-width": "1px",
            "border-block-start-style": "solid",
            "border-block-end-width": "1px",
            "border-block-end-style": "solid",
        },
    },
    {
        "selectorText": "table[rules=rows i] > tr, table[rules=rows i] > thead > tr,\ntable[rules=rows i] > tbody > tr, table[rules=rows i] > tfoot > tr",
        "type": "CSSStyleRule",
        "style": {
            "border-block-start-width": "1px",
            "border-block-start-style": "solid",
            "border-block-end-width": "1px",
            "border-block-end-style": "solid",
        },
    },
    {
        "selectorText": "table",
        "type": "CSSStyleRule",
        "style": {
            "font-weight": "initial",
            "font-style": "initial",
            "font-variant": "initial",
            "font-size": "initial",
            "line-height": "initial",
            "white-space": "initial",
            "text-align": "initial",
        },
    },
    {
        "selectorText": "table > form, thead > form, tbody > form, tfoot > form, tr > form",
        "type": "CSSStyleRule",
        "style": {"display": "none"},
    },
    {
        "selectorText": "input, select, option, optgroup, button, textarea",
        "type": "CSSStyleRule",
        "style": {"text-indent": "initial"},
    },
    {
        "selectorText": "input[type=radio i], input[type=checkbox i], input[type=reset i], input[type=button i], input[type=submit i], input[type=search i], select, button",
        "type": "CSSStyleRule",
        "style": {"box-sizing": "border-box"},
    },
    {
        "selectorText": "textarea",
        "type": "CSSStyleRule",
        "style": {"white-space": "pre-wrap"},
    },
    {
        "selectorText": "input:not([type=image i]), textarea",
        "type": "CSSStyleRule",
        "style": {"box-sizing": "border-box"},
    },
    {
        "selectorText": "hr",
        "type": "CSSStyleRule",
        "style": {
            "color": "gray",
            "border-style": "inset",
            "border-width": "1px",
            "margin-block-start": "0.5em",
            "margin-inline-end": "auto",
            "margin-block-end": "0.5em",
            "margin-inline-start": "auto",
        },
    },
    {
        "selectorText": "hr[align=left i]",
        "type": "CSSStyleRule",
        "style": {"margin-left": "0", "margin-right": "auto"},
    },
    {
        "selectorText": "hr[align=right i]",
        "type": "CSSStyleRule",
        "style": {"margin-left": "auto", "margin-right": "0"},
    },
    {
        "selectorText": "hr[align=center i]",
        "type": "CSSStyleRule",
        "style": {"margin-left": "auto", "margin-right": "auto"},
    },
    {
        "selectorText": "hr[color], hr[noshade]",
        "type": "CSSStyleRule",
        "style": {"border-style": "solid"},
    },
    {
        "selectorText": "fieldset",
        "type": "CSSStyleRule",
        "style": {
            "display": "block",
            "margin-inline-start": "2px",
            "margin-inline-end": "2px",
            "border": "groove 2px ThreeDFace",
            "padding-block-start": "0.35em",
            "padding-inline-end": "0.625em",
            "padding-block-end": "0.75em",
            "padding-inline-start": "0.625em",
            "min-width": "min-content",
        },
    },
    {
        "selectorText": "legend",
        "type": "CSSStyleRule",
        "style": {"padding-inline-start": "2px", "padding-inline-end": "2px"},
    },
    {
        "selectorText": "iframe",
        "type": "CSSStyleRule",
        "style": {"border": "2px inset"},
    },
    {
        "selectorText": "video",
        "type": "CSSStyleRule",
        "style": {"object-fit": "contain"},
    },
    {
        "selectorText": "img[align=left i]",
        "type": "CSSStyleRule",
        "style": {"margin-right": "3px"},
    },
    {
        "selectorText": "img[align=right i]",
        "type": "CSSStyleRule",
        "style": {"margin-left": "3px"},
    },
    {
        "selectorText": 'iframe[frameborder="0"], iframe[frameborder=no i]',
        "type": "CSSStyleRule",
        "style": {"border": "none"},
    },
    {
        "selectorText": "applet[align=left i], embed[align=left i], iframe[align=left i],\nimg[align=left i], input[type=image i][align=left i], object[align=left i]",
        "type": "CSSStyleRule",
        "style": {"float": "left"},
    },
    {
        "selectorText": "applet[align=right i], embed[align=right i], iframe[align=right i],\nimg[align=right i], input[type=image i][align=right i], object[align=right i]",
        "type": "CSSStyleRule",
        "style": {"float": "right"},
    },
    {
        "selectorText": "applet[align=top i], embed[align=top i], iframe[align=top i],\nimg[align=top i], input[type=image i][align=top i], object[align=top i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "top"},
    },
    {
        "selectorText": "applet[align=baseline i], embed[align=baseline i], iframe[align=baseline i],\nimg[align=baseline i], input[type=image i][align=baseline i], object[align=baseline i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "baseline"},
    },
    {
        "selectorText": "applet[align=texttop i], embed[align=texttop i], iframe[align=texttop i],\nimg[align=texttop i], input[type=image i][align=texttop i], object[align=texttop i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "text-top"},
    },
    {
        "selectorText": "applet[align=absmiddle i], embed[align=absmiddle i], iframe[align=absmiddle i],\nimg[align=absmiddle i], input[type=image i][align=absmiddle i], object[align=absmiddle i],\napplet[align=abscenter i], embed[align=abscenter i], iframe[align=abscenter i],\nimg[align=abscenter i], input[type=image i][align=abscenter i], object[align=abscenter i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "middle"},
    },
    {
        "selectorText": "applet[align=bottom i], embed[align=bottom i], iframe[align=bottom i],\nimg[align=bottom i], input[type=image i][align=bottom i],\nobject[align=bottom i]",
        "type": "CSSStyleRule",
        "style": {"vertical-align": "bottom"},
    },
    {
        "selectorText": "textarea",
        "type": "CSSStyleRule",
        "style": {"white-space": "pre-wrap"},
    },
]
